# Dubious tags

Detects and lists dubious OSM tags - with explanation why they are suspicious. In many cases it is possible to find better tagging for affected objects, making OSM data more usable and more clear.

This is intended to cover rather rarely used tags.

It definitely should not include tags that I merely dislike but are accepted by OSM community.

It does not include all problematic tags in OSM or even all problematic tags that I am aware of.

# Warning

Do not change or edits this tags blindly! This tags are listed here rather than [proposed for bot edit](https://wiki.openstreetmap.org/wiki/Mechanical_Edits/Mateusz_Konieczny_-_bot_account#Active_tasks) as it is not safe to change them without verification or local knowledge.

And blindly editing them in manual edits, without thinking is actually worse than automated bot edit. It has all bot edits problems, adds some new one and is a pure waste of time.


Not editing is better than editing and breaking things.

Though in some cases you may have local knowledge or better understanding. In such case follow [OSM rules](https://wiki.openstreetmap.org/wiki/Automated_Edits_code_of_conduct) if it is possible to reliably retag objects without individual review and local community agrees with such idea.



# Usage

## OpenStreetMap discussions

If things go well then using this list looks like [https://www.openstreetmap.org/changeset/133103215](https://www.openstreetmap.org/changeset/133103215) or [https://www.openstreetmap.org/changeset/142498355](https://www.openstreetmap.org/changeset/142498355)

## Taginfo listing

It is displayed at [Taginfo](https://taginfo.openstreetmap.org/projects) - see [listing of this specific project](https://taginfo.openstreetmap.org/projects/dubious_tags_mk).

It will be also listed at project tab of tags and keys listed here as dubious.

## As Python package

```
import dubious_tags

print(dubious_tags.list.dubious_tags_with_explanation())
```

Note that this will make calls to taginfo to fetch some data.

[tags_in_taginfo_format.json](tags_in_taginfo_format.json) file is generated by build script.

# Installation as a python package

`pip install dubious_tags`

It is uploaded to [pypi.org](https://pypi.org/project/dubious_tags/)

# Run tests

```
python3 -m unittest
```
